import pandas as pd
from typing import List



def load_file(filepath, header=0, as_dataframe=False):
    '''It should load any kind of file formats'''

    ext = file_ext(filepath)

    if ext == 'csv':
        df = pd.read_csv(filepath, header=header)
    elif ext in ['xlsx', 'xls']:
        df = pd.read_excel(filepath, header=header)
    else:
        print("Invalid file format")
        return None
    
    if as_dataframe:
        return df

    return df.to_dict('list')

def write(filepath, items: List[dict], mode='w'):
    header = True
    if mode == 'a':
        header = False

    ext = file_ext(filepath)

    if ext == 'csv':
        df = pd.DataFrame(items) 
        df.to_csv(filepath, index=False, mode=mode, header=header)


def file_ext(filepath):
    filename = filepath.name
    return filename.split('.')[-1]


from ..himan.pandas.utils import file_ext
from pathlib import Path, PurePath



def get_path(filename):
    return PurePath(Path(__file__).parent, 'samples', 'csv', filename)


def test_should_extract_extension():
    filepath= get_path('sample.csv')
    ext = file_ext(filepath)

    assert 'csv' == ext


from ..himan.pandas.utils import load_file
from pandas import DataFrame
from pathlib import Path, PurePath



def get_path(filename):
    return PurePath(Path(__file__).parent, 'samples', 'csv', filename)


filepath = get_path('sample.csv')

def test_should_read_csv_file():
    item = load_file(filepath)

    keys = item.keys()
    assert len(keys) == 2
    assert 'name' in item.keys()

def test_should_accept_no_header_parameter():
    item = load_file(filepath, header=None)

    keys = item.keys()
    assert len(keys) == 2
    assert 'name' not in item.keys()
    assert item[0][1:] == ['John', 'Peter']

def test_should_read_as_dataframe():
    item = load_file(filepath, as_dataframe=True)

    assert isinstance(item, DataFrame)



import os
from pathlib import Path, PurePath
from ..himan.pandas.utils import load_file, write



def get_path(filename):
    return PurePath(Path(__file__).parent, 'samples', 'csv', filename)



def test_should_write_csv_file():
    filename = get_path('sample_01.csv')

    items = [
        {'name': 'John', 'surname': 'Smith', 'age': 18},
        {'name': 'Peter', 'surname': 'Adams', 'age': 30}
    ]

    write(filename, items)

    item = load_file(filename)

    keys = item.keys()
    assert len(keys) == 3
    assert 'age' in item.keys()

    os.remove(filename)


def test_should_append_csv_file():
    filename = get_path('sample_01.csv')

    items = [
        {'name': 'John', 'surname': 'Smith', 'age': 18},
        {'name': 'Peter', 'surname': 'Adams', 'age': 30}
    ]

    write(filename, items)

    item = load_file(filename)

    keys = item.keys()
    assert len(keys) == 3
    assert 'age' in item.keys()

    new_item = [
        {'name': 'Paul', 'surname': 'Sanders', 'age': 21},
    ]

    write(filename, new_item, 'a')

    item = load_file(filename)
    assert len(item['name']) == 3

    os.remove(filename)

